# nvidia_updater

Check for newer NVIDIA GPU drivers without opening a browser. Uses TinyNvidiaUpdateChecker from C:/USB/system/nvidia-updater/.

## Structure

- `schema.json`: Interface
- `tool.py`: CLI
- worker.py: Background
